/* Copyright 2011, Martin Koller, kollix@aon.at

  This file is part of ShowImage.

  ShowImage is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  ShowImage is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with ShowImage.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _ImageWidget_H_
#define _ImageWidget_H_

#include <QWidget>
#include <QImage>
#include <QStringList>

#include <kurl.h>

class KMenu;
class KToggleFullScreenAction;
class KActionCollection;
class QAction;
class QTimer;

class Overlay;

//--------------------------------------------------------------------------------

class ImageWidget : public QWidget
{
  Q_OBJECT

  public:
    ImageWidget(QWidget *parent = 0);

    bool showImage(const KUrl &url);

    void setFullScreen();

    virtual QSize sizeHint() const;

    QAction *getAction(const QString &name) const;

  protected:
    virtual void paintEvent(QPaintEvent *event);
    virtual void resizeEvent(QResizeEvent *event);
    virtual void contextMenuEvent(QContextMenuEvent *event);
    virtual void mouseMoveEvent(QMouseEvent *event);
    virtual void leaveEvent(QEvent *);
    virtual void mousePressEvent(QMouseEvent *event);
    virtual void mouseReleaseEvent(QMouseEvent *event);
    virtual void wheelEvent(QWheelEvent *event);
    virtual void keyPressEvent(QKeyEvent *event);

  public slots:
    void rotateLeft();
    void rotateRight();
    void mirrorHor();
    void mirrorVer();
    void origSize();
    void fitToPage();
    void zoomIn();
    void zoomOut();
    void properties();
    void save();
    void saveAs();
    void copy();
    void deleteFile();
    void showAbout();
    void prior();
    void next();
    void first();
    void last();

  private slots:
    void toggleFullScreen();
    void wheelSettingChanged(bool checked);
    void mouseButtonNext(int num);
    void mouseButtonPrev(int num);
    void configureShortcuts();
    void cursorHideSlot();

  private:  // methods
    void adaptView();
    void checkResize();
    void getFileNames();
    void moveStartPos(int dx, int dy);
    void setTitle();

    enum BgType { Black, Chequered };
    void setBackground(BgType t);

  private:  // members
    KUrl sourceUrl;
    QImage origImage;
    QImage image;
    QPoint startPos, mousePos, mousePressPos;
    KMenu *menu;
    KToggleFullScreenAction *fullScreenAction;
    QStringList fileNames;  // in current directory
    bool wheelToBrowse;
    int mouseButtonForNext, mouseButtonForPrev;
    bool newImageInOrigSize;
    KActionCollection *actionCollection;
    Overlay *overlay;
    QTimer *cursorTimer;  // to disable mouse cursor
};

#endif
