/* Copyright 2011, Martin Koller, kollix@aon.at

  This file is part of ShowImage.

  ShowImage is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  ShowImage is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with ShowImage.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <Overlay.hxx>

#include <QHBoxLayout>
#include <QToolButton>
#include <QLabel>
#include <QPalette>
#include <QLinearGradient>
#include <QAction>

//--------------------------------------------------------------------------------

Overlay::Overlay(ImageWidget *parent)
  : QWidget(parent)
{
  QPalette pal = palette();
  QLinearGradient grad(0, 0, 1, 0);
  grad.setColorAt(0.0, QColor(0, 0, 0, 190));
  grad.setColorAt(1.0, QColor(255, 255, 255, 190));
  grad.setCoordinateMode(QGradient::ObjectBoundingMode);
  pal.setBrush(backgroundRole(), grad);
  setPalette(pal);
  setAutoFillBackground(true);

  QHBoxLayout *l = new QHBoxLayout(this);
  l->setContentsMargins(0, 0, 0, 0);

  QStringList actions;
  actions << "fullScreen" << "first" << "prior" << "next" << "last" << "rotateLeft" << "rotateRight";

  foreach (const QString &name, actions)
  {
    QToolButton *b = new QToolButton;
    QAction *action = parent->getAction(name);
    b->setDefaultAction(action);
    l->addWidget(b);
  }

  label = new QLabel;
  pal = label->palette();
  pal.setColor(label->foregroundRole(), Qt::white);
  label->setPalette(pal);
  l->addWidget(label);
}

//--------------------------------------------------------------------------------

void Overlay::setText(const QString &text)
{
  label->setText(text);
}

//--------------------------------------------------------------------------------

void Overlay::resizeEvent(QResizeEvent *)
{
  QList<QToolButton*> buttons = findChildren<QToolButton*>();
  foreach (QToolButton *b, buttons)
  {
    b->setMaximumSize(height(), height());
    b->setIconSize(QSize(height() - 6, height() - 6));
  }
}

//--------------------------------------------------------------------------------

void Overlay::setSmall()
{
  setFixedHeight(qMax(32, fontMetrics().height() * 2 + 2));
}

//--------------------------------------------------------------------------------

void Overlay::setLarge()
{
  setFixedHeight(qMax(50, fontMetrics().height() * 2 + 2));
}

//--------------------------------------------------------------------------------
