/* Copyright 2011, Martin Koller, kollix@aon.at

  This file is part of ShowImage.

  ShowImage is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  ShowImage is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with ShowImage.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ImageWidget.hxx>

#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <kurl.h>
#include <kmessagebox.h>
#include <kfiledialog.h>
#include <kimageio.h>

#include <stdio.h>

//--------------------------------------------------------------------------------

ImageWidget *openImage(const KUrl &url, int &count)
{
  ImageWidget *viewer = new ImageWidget;
  if ( !viewer->showImage(url) )
  {
    if ( QFileInfo(url.path()).isDir() )  // not a file but a dir given
      KMessageBox::sorry(0, i18n("Can not load any image in '%1'").arg(url.pathOrUrl()));
    else
      KMessageBox::sorry(0, i18n("Can not load image '%1'").arg(url.pathOrUrl()));

    delete viewer;
    viewer = 0;
  }
  else
  {
    viewer->show();
    count++;
  }
  return viewer;
}

//--------------------------------------------------------------------------------

int main(int argc, char **argv)
{
  KAboutData about("showimage", "", ki18n("ShowImage"),
                   "1.8.2", ki18n("A simple image viewer"), KAboutData::License_GPL_V3,
                   ki18n("(c) 2011-2014 Martin Koller"),  // copyright
                   KLocalizedString(),  // added text
                   "http://kde-apps.org/content/show.php?content=143977",  // homepage
                   "kollix@aon.at");  // bugs to

  about.addAuthor(ki18n("Martin Koller"), ki18n("Developer"), "kollix@aon.at");

  KCmdLineOptions options;
  options.add("fullscreen", ki18n("Start in fullscreen mode"));
  options.add("mimetypes", ki18n("List all readable image MimeTypes"));
  options.add("+file_or_dir", ki18n("Start with given file or directory"));
  options.add("+[file_or_dir...]", ki18n("More files  or directories to open"));

  KCmdLineArgs::addCmdLineOptions(options);
  KCmdLineArgs::init(argc, argv, &about);

  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

  KApplication app;

  // produce a list of MimeTypes which showimage can handle (can be used inside the .desktop file)
  if ( args->isSet("mimetypes") )
  {
    printf("MimeType=inode/directory;%s;\n", KImageIO::mimeTypes(KImageIO::Reading).join(";").toAscii().constData());
    return 0;
  }

  int count = 0;  // number of open windows
  ImageWidget *viewer = 0;

  if ( args->count() == 0 )
  {
    QString image =
      KFileDialog::getOpenFileName(KUrl(), KImageIO::mimeTypes(KImageIO::Reading).join(" "),
                                   0, i18n("Open Image..."));
    if ( image.isEmpty() )
      return -1;

    viewer = openImage(KUrl(image), count);
  }
  else
  {
    for (int i = 0; i < args->count(); i++)
      viewer = openImage(args->url(i), count);
  }

  if ( viewer && args->isSet("fullscreen") )
    viewer->setFullScreen();

  return (count == 0) ? -1 : app.exec();
}
